@@ -26,17 +26,7 @@ __all__ = [
 
 import inspect
 import types
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Callable,
-    Dict,
-    Iterable,
-    List,
-    Optional,
-    TypeVar,
-    Union,
-)
+from typing import TYPE_CHECKING, Any, Callable, Iterable, List, Optional, Sequence
 
 import numpy as np
 
@@ -45,7 +35,7 @@ from ..animation.animation import Animation
 from ..constants import DEFAULT_POINTWISE_FUNCTION_RUN_TIME, DEGREES, OUT
 from ..mobject.mobject import Group, Mobject
 from ..mobject.opengl_mobject import OpenGLGroup, OpenGLMobject
-from ..utils.paths import path_along_arc, straight_path
+from ..utils.paths import path_along_arc
 from ..utils.rate_functions import smooth, squish_rate_func
 
 if TYPE_CHECKING:
@@ -126,7 +116,7 @@ class Transform(Animation):
             scene.remove(self.mobject)
             scene.add(self.target_mobject)
 
-    def get_all_mobjects(self) -> List[Mobject]:
+    def get_all_mobjects(self) -> Sequence[Mobject]:
         return [
             self.mobject,
             self.starting_mobject,
@@ -318,9 +308,8 @@ class ApplyFunction(Transform):
         super().__init__(mobject, **kwargs)
 
     def create_target(self) -> Any:
-        assert isinstance(self.mobject, Mobject)
         target = self.function(self.mobject.copy())
-        if not isinstance(target, Mobject):
+        if not isinstance(target, (Mobject, OpenGLMobject)):
             raise TypeError(
                 "Functions passed to ApplyFunction must return object of type Mobject"
             )
@@ -499,7 +488,7 @@ class FadeTransform(Transform):
         source.replace(target, stretch=self.stretch, dim_to_match=self.dim_to_match)
         source.set_opacity(0)
 
-    def get_all_mobjects(self):
+    def get_all_mobjects(self) -> Sequence[Mobject]:
         return [
             self.mobject,
             self.starting_mobject,
