@@ -3,15 +3,16 @@
 __all__ = ["ParametricFunction", "FunctionGraph"]
 
 
-import math
+import numpy as np
 
 from .. import config
 from ..constants import *
 from ..mobject.types.vectorized_mobject import VMobject
 from ..utils.color import YELLOW
+from .opengl_compatibility import ConvertToOpenGL
 
 
-class ParametricFunction(VMobject):
+class ParametricFunction(VMobject, metaclass=ConvertToOpenGL):
     """A parametric curve.
 
     Examples
@@ -25,7 +26,7 @@ class ParametricFunction(VMobject):
                 return np.array((np.sin(2 * t), np.sin(3 * t), 0))
 
             def construct(self):
-                func = ParametricFunction(self.func, t_max = TAU, fill_opacity=0).set_color(RED)
+                func = ParametricFunction(self.func, t_range = np.array([0, TAU]), fill_opacity=0).set_color(RED)
                 self.add(func.scale(3))
 
     .. manim:: ThreeDParametricSpring
@@ -38,7 +39,7 @@ class ParametricFunction(VMobject):
                         1.2 * np.cos(u),
                         1.2 * np.sin(u),
                         u * 0.05
-                    ]), color=RED, t_min=-3 * TAU, t_max=5 * TAU,
+                    ]), color=RED, t_range = np.array([-3*TAU, 5*TAU, 0.01])
                 ).set_shade_in_3d(True)
                 axes = ThreeDAxes()
                 self.add(axes, curve1)
@@ -56,16 +57,16 @@ class ParametricFunction(VMobject):
         **kwargs
     ):
         self.function = function
-        t_range = np.array([0, 1, 0.01]) if t_range is None else t_range
+        t_range = [0, 1, 0.01] if t_range is None else t_range
         if len(t_range) == 2:
-            t_range = [*t_range, 0.01]
+            t_range = np.array([*t_range, 0.01])
 
         self.dt = dt
         self.discontinuities = [] if discontinuities is None else discontinuities
         self.use_smoothing = use_smoothing
         self.t_min, self.t_max, self.t_step = t_range
 
-        VMobject.__init__(self, **kwargs)
+        super().__init__(**kwargs)
 
     def get_function(self):
         return self.function
@@ -79,15 +80,17 @@ class ParametricFunction(VMobject):
             lambda t: self.t_min <= t <= self.t_max, self.discontinuities
         )
         discontinuities = np.array(list(discontinuities))
-        boundary_times = [
-            self.t_min,
-            self.t_max,
-            *(discontinuities - self.dt),
-            *(discontinuities + self.dt),
-        ]
+        boundary_times = np.array(
+            [
+                self.t_min,
+                self.t_max,
+                *(discontinuities - self.dt),
+                *(discontinuities + self.dt),
+            ]
+        )
         boundary_times.sort()
         for t1, t2 in zip(boundary_times[0::2], boundary_times[1::2]):
-            t_range = [*np.arange(t1, t2, self.t_step), t2]
+            t_range = np.array([*np.arange(t1, t2, self.t_step), t2])
             points = np.array([self.function(t) for t in t_range])
             self.start_new_path(points[0])
             self.add_points_as_corners(points[1:])
@@ -96,6 +99,8 @@ class ParametricFunction(VMobject):
             self.make_smooth()
         return self
 
+    init_points = generate_points
+
 
 class FunctionGraph(ParametricFunction):
     def __init__(self, function, x_range=None, color=YELLOW, **kwargs):
