@@ -16,6 +16,7 @@ from ..mobject.types.vectorized_mobject import VGroup
 from ..utils.bezier import interpolate
 from ..utils.color import LIGHT_GREY
 from ..utils.config_ops import merge_dicts_recursively
+from ..utils.deprecation import deprecated
 from ..utils.simple_functions import fdiv
 from ..utils.space_ops import normalize
 
@@ -80,7 +81,7 @@ class NumberLine(Line):
         # ticks
         include_ticks=True,
         tick_size=0.1,
-        numbers_with_elongated_ticks=[],
+        numbers_with_elongated_ticks=None,
         longer_tick_multiple=2,
         # visuals
         color=LIGHT_GREY,
@@ -94,15 +95,31 @@ class NumberLine(Line):
         include_numbers=False,
         label_direction=DOWN,
         line_to_number_buff=MED_SMALL_BUFF,
-        decimal_number_config={"num_decimal_places": 0, "font_size": 24},
-        numbers_to_exclude=[],
+        decimal_number_config=None,
+        numbers_to_exclude=None,
+        numbers_to_include=None,
         # temp, because DecimalNumber() needs to be updated
         number_scale_value=0.75,
         **kwargs
     ):
+        # avoid mutable arguments in defaults
+        if decimal_number_config is None:
+            decimal_number_config = {
+                "num_decimal_places": 0,
+                "font_size": 24,
+            }  # font_size does nothing
+        if numbers_to_exclude is None:
+            numbers_to_exclude = []
+        if numbers_with_elongated_ticks is None:
+            numbers_with_elongated_ticks = []
+
         if x_range is None:
-            x_range = [-config["frame_x_radius"], config["frame_x_radius"], 1.0]
-        if len(x_range) == 2:
+            x_range = [
+                round(-config["frame_x_radius"]),
+                round(config["frame_x_radius"]),
+                1.0,
+            ]
+        elif len(x_range) == 2:
             # adds x_step if not specified. not sure how to feel about this. a user can't know default without peeking at source code
             x_range = [*x_range, 1]
 
@@ -128,6 +145,7 @@ class NumberLine(Line):
         self.line_to_number_buff = line_to_number_buff
         self.decimal_number_config = decimal_number_config
         self.numbers_to_exclude = numbers_to_exclude
+        self.numbers_to_include = numbers_to_include
         self.number_scale_value = number_scale_value
 
         super().__init__(
@@ -153,8 +171,10 @@ class NumberLine(Line):
             self.add_ticks()
 
         self.rotate(self.rotation)
-        if self.include_numbers:
-            self.add_numbers(excluding=self.numbers_to_exclude)
+        if self.include_numbers or self.numbers_to_include is not None:
+            self.add_numbers(
+                x_values=self.numbers_to_include, excluding=self.numbers_to_exclude
+            )
 
     def rotate_about_zero(self, angle, axis=OUT, **kwargs):
         return self.rotate_about_number(0, angle, axis, **kwargs)
@@ -250,13 +270,14 @@ class NumberLine(Line):
         if x_values is None:
             x_values = self.get_tick_range()
 
+        if excluding is None:
+            excluding = self.numbers_to_exclude
+
         kwargs["font_size"] = font_size
 
         numbers = VGroup()
         for x in x_values:
-            if x in self.numbers_to_exclude:
-                continue
-            if excluding is not None and x in excluding:
+            if x in excluding:
                 continue
             numbers.add(self.get_number_mobject(x, **kwargs))
         self.add(numbers)
@@ -297,6 +318,12 @@ class UnitInterval(NumberLine):
         )
 
 
+@deprecated(
+    since="v0.7.0",
+    until="v0.9.0",
+    replacement="NumberLine",
+    message="NumberLineOld will be removed alongside GraphScene ",
+)
 class NumberLineOld(Line):
     """The old version of :class:`NumberLine`.
 
