@@ -6,6 +6,7 @@ __all__ = ["SampleSpace", "BarChart"]
 from ..constants import *
 from ..mobject.geometry import Line, Rectangle
 from ..mobject.mobject import Mobject
+from ..mobject.opengl_mobject import OpenGLMobject
 from ..mobject.svg.brace import Brace
 from ..mobject.svg.tex_mobject import MathTex, Tex
 from ..mobject.types.vectorized_mobject import VGroup
@@ -102,7 +103,7 @@ class SampleSpace(Rectangle):
         braces = VGroup()
         for label, part in zip(labels, parts):
             brace = Brace(part, direction, min_num_quads=min_num_quads, buff=buff)
-            if isinstance(label, Mobject):
+            if isinstance(label, (Mobject, OpenGLMobject)):
                 label_mob = label
             else:
                 label_mob = MathTex(label)
