@@ -1,17 +1,22 @@
 """Mobject representing curly braces."""
 
-__all__ = ["Brace", "BraceLabel", "BraceText", "BraceBetweenPoints"]
+__all__ = ["Brace", "BraceLabel", "ArcBrace", "BraceText", "BraceBetweenPoints"]
 
+from typing import Optional, Sequence
 
 import numpy as np
 
+from manim._config import config
+from manim.mobject.opengl_compatibility import ConvertToOpenGL
+
 from ...animation.composition import AnimationGroup
 from ...animation.fading import FadeIn
 from ...animation.growing import GrowFromCenter
 from ...constants import *
-from ...mobject.geometry import Line
+from ...mobject.geometry import Arc, Line
 from ...mobject.svg.svg_path import SVGPathMobject
 from ...mobject.svg.tex_mobject import MathTex, Tex
+from ...mobject.types.opengl_vectorized_mobject import OpenGLVMobject
 from ...mobject.types.vectorized_mobject import VMobject
 from ...utils.color import BLACK
 
@@ -26,7 +31,7 @@ class Brace(SVGPathMobject):
     ----------
     mobject : :class:`~.Mobject`
         The mobject adjacent to which the brace is placed.
-    direction : Optional[Union[:class:`list`, :class:`numpy.array`]]
+    direction :
         The direction from which the brace faces the mobject.
 
     See Also
@@ -54,7 +59,7 @@ class Brace(SVGPathMobject):
     def __init__(
         self,
         mobject,
-        direction=DOWN,
+        direction: Optional[Sequence[float]] = DOWN,
         buff=0.2,
         sharpness=2,
         stroke_width=0,
@@ -118,14 +123,17 @@ class Brace(SVGPathMobject):
 
     def get_tip(self):
         # Returns the position of the seventh point in the path, which is the tip.
-        return self.points[28]  # = 7*4
+        if config["renderer"] == "opengl":
+            return self.get_points()[34]
+
+        return self.get_points()[28]  # = 7*4
 
     def get_direction(self):
         vect = self.get_tip() - self.get_center()
         return vect / np.linalg.norm(vect)
 
 
-class BraceLabel(VMobject):
+class BraceLabel(VMobject, metaclass=ConvertToOpenGL):
     def __init__(
         self,
         obj,
@@ -137,10 +145,11 @@ class BraceLabel(VMobject):
     ):
         self.label_constructor = label_constructor
         self.label_scale = label_scale
-        VMobject.__init__(self, **kwargs)
+        super().__init__(**kwargs)
+
         self.brace_direction = brace_direction
         if isinstance(obj, list):
-            obj = VMobject(*obj)
+            obj = self.get_group_class()(*obj)
         self.brace = Brace(obj, brace_direction, **kwargs)
 
         if isinstance(text, tuple) or isinstance(text, list):
@@ -158,7 +167,7 @@ class BraceLabel(VMobject):
 
     def shift_brace(self, obj, **kwargs):
         if isinstance(obj, list):
-            obj = VMobject(*obj)
+            obj = self.get_group_class()(*obj)
         self.brace = Brace(obj, self.brace_direction, **kwargs)
         self.brace.put_at_tip(self.label)
         self.submobjects[0] = self.brace
@@ -195,11 +204,11 @@ class BraceBetweenPoints(Brace):
 
     Parameters
     ----------
-    point_1 : Union[:class:`list`, :class:`numpy.array`]
+    point_1 :
         The first point.
-    point_2 : Union[:class:`list`, :class:`numpy.array`]
+    point_2 :
         The second point.
-    direction : Optional[Union[:class:`list`, :class:`numpy.array`]]
+    direction :
         The direction from which the brace faces towards the points.
 
     Examples
@@ -216,8 +225,91 @@ class BraceBetweenPoints(Brace):
                     self.wait(2)
     """
 
-    def __init__(self, point_1, point_2, direction=ORIGIN, **kwargs):
+    def __init__(
+        self,
+        point_1: Optional[Sequence[float]],
+        point_2: Optional[Sequence[float]],
+        direction: Optional[Sequence[float]] = ORIGIN,
+        **kwargs
+    ):
         if all(direction == ORIGIN):
             line_vector = np.array(point_2) - np.array(point_1)
             direction = np.array([line_vector[1], -line_vector[0], 0])
         Brace.__init__(self, Line(point_1, point_2), direction=direction, **kwargs)
+
+
+class ArcBrace(Brace):
+    """Creates a :class:`~Brace` that wraps around an :class:`~.Arc`.
+
+    The direction parameter allows the brace to be applied
+    from outside or inside the arc.
+
+    .. warning::
+        The :class:`ArcBrace` is smaller for arcs with smaller radii.
+
+    .. note::
+        The :class:`ArcBrace` is initially a vertical :class:`Brace` defined by the length of the :class:`~.Arc`, but is scaled down to match the start and end angles. An exponential function is then applied after it is shifted based on the radius of the arc.
+
+        The scaling effect is not applied for arcs with radii smaller than 1 to prevent over-scaling.
+
+    Parameters
+    ----------
+    arc
+        The :class:`~.Arc` that wraps around the :class:`Brace` mobject.
+    direction
+        The direction from which the brace faces the arc.
+        ``LEFT`` for inside the arc, and ``RIGHT`` for the outside.
+
+    Example
+    -------
+        .. manim:: ArcBraceExample
+            :save_last_frame:
+            :ref_classes: Arc
+
+            class ArcBraceExample(Scene):
+                def construct(self):
+                    arc_1 = Arc(radius=1.5,start_angle=0,angle=2*PI/3).set_color(RED)
+                    brace_1 = ArcBrace(arc_1,LEFT)
+                    group_1 = VGroup(arc_1,brace_1)
+
+                    arc_2 = Arc(radius=3,start_angle=0,angle=5*PI/6).set_color(YELLOW)
+                    brace_2 = ArcBrace(arc_2)
+                    group_2 = VGroup(arc_2,brace_2)
+
+                    arc_3 = Arc(radius=0.5,start_angle=-0,angle=PI).set_color(BLUE)
+                    brace_3 = ArcBrace(arc_3)
+                    group_3 = VGroup(arc_3,brace_3)
+
+                    arc_4 = Arc(radius=0.2,start_angle=0,angle=3*PI/2).set_color(GREEN)
+                    brace_4 = ArcBrace(arc_4)
+                    group_4 = VGroup(arc_4,brace_4)
+
+                    arc_group = VGroup(group_1, group_2, group_3, group_4).arrange_in_grid(buff=1.5)
+                    self.add(arc_group.center())
+
+    """
+
+    def __init__(
+        self,
+        arc: Arc = Arc(start_angle=-1, angle=2, radius=1),
+        direction: Sequence[float] = RIGHT,
+        **kwargs
+    ):
+        arc_end_angle = arc.start_angle + arc.angle
+        line = Line(UP * arc.start_angle, UP * arc_end_angle)
+        scale_shift = RIGHT * np.log(arc.radius)
+
+        if arc.radius >= 1:
+            line.scale(arc.radius, about_point=ORIGIN)
+            Brace.__init__(self, line, direction=direction, **kwargs)
+            self.scale(1 / (arc.radius), about_point=ORIGIN)
+        else:
+            Brace.__init__(self, line, direction=direction, **kwargs)
+
+        if arc.radius >= 0.3:
+            self.shift(scale_shift)
+        else:
+            self.shift(RIGHT * np.log(0.3))
+
+        self.apply_complex_function(np.exp)
+        self.shift(arc.get_arc_center())
