@@ -171,16 +171,18 @@ __all__ = [
 import operator as op
 from functools import reduce
 
-from ... import config, logger
+from ... import config
 from ...constants import *
 from ...mobject.opengl_geometry import OpenGLLine
 from ...mobject.svg.opengl_svg_mobject import OpenGLSVGMobject
 from ...mobject.svg.opengl_svg_path import OpenGLSVGPathMobject
+from ...mobject.svg.tex_mobject import MathTex, Tex
 from ...mobject.types.opengl_vectorized_mobject import (
     OpenGLVectorizedPoint,
     OpenGLVGroup,
 )
 from ...utils.color import BLACK
+from ...utils.deprecation import deprecated
 from ...utils.strings import split_string_list_to_isolate_substrings
 from ...utils.tex_file_writing import tex_to_svg_file
 from .style_utils import parse_style
@@ -597,19 +599,13 @@ class OpenGLTitle(OpenGLTex):
             self.underline = underline
 
 
+@deprecated(until="v0.7.0", replacement="MathTex")
 class OpenGLTexMobject(OpenGLMathTex):
     def __init__(self, *tex_strings, **kwargs):
-        logger.warning(
-            "TexMobject has been deprecated (due to its confusing name) "
-            "in favour of MathTex. Please use MathTex instead!"
-        )
         MathTex.__init__(self, *tex_strings, **kwargs)
 
 
+@deprecated(until="v0.7.0", replacement="Tex")
 class OpenGLTextMobject(OpenGLTex):
     def __init__(self, *text_parts, **kwargs):
-        logger.warning(
-            "TextMobject has been deprecated (due to its confusing name) "
-            "in favour of Tex. Please use Tex instead!"
-        )
         Tex.__init__(self, *text_parts, **kwargs)
