@@ -13,12 +13,15 @@ __all__ = [
 
 import itertools as it
 import sys
-from typing import Iterable, Optional, Sequence, Union
+import typing
+from abc import ABCMeta
+from typing import Optional, Sequence, Union
 
 import colour
 import numpy as np
 from PIL.Image import Image
 
+from ... import config
 from ...constants import *
 from ...mobject.mobject import Mobject
 from ...mobject.three_d_utils import get_3d_vmob_gradient_start_and_end_points
@@ -33,6 +36,8 @@ from ...utils.color import BLACK, WHITE, color_to_rgba
 from ...utils.iterables import make_even, stretch_array_to_length, tuplify
 from ...utils.simple_functions import clip_in_place
 from ...utils.space_ops import rotate_vector, shoelace_direction
+from ..opengl_compatibility import ConvertToOpenGL
+from .opengl_vectorized_mobject import OpenGLVMobject
 
 # TODO
 # - Change cubic curve groups to have 4 points instead of 3
@@ -246,9 +251,7 @@ class VMobject(Mobject):
         )
         if sheen_factor:
             self.set_sheen(
-                factor=sheen_factor,
-                direction=sheen_direction,
-                family=family,
+                factor=sheen_factor, direction=sheen_direction, family=family
             )
         if background_image:
             self.color_using_background_image(background_image)
@@ -311,17 +314,10 @@ class VMobject(Mobject):
 
     def fade(self, darkness=0.5, family=True):
         factor = 1.0 - darkness
-        self.set_fill(
-            opacity=factor * self.get_fill_opacity(),
-            family=False,
-        )
-        self.set_stroke(
-            opacity=factor * self.get_stroke_opacity(),
-            family=False,
-        )
+        self.set_fill(opacity=factor * self.get_fill_opacity(), family=False)
+        self.set_stroke(opacity=factor * self.get_stroke_opacity(), family=False)
         self.set_background_stroke(
-            opacity=factor * self.get_stroke_opacity(background=True),
-            family=False,
+            opacity=factor * self.get_stroke_opacity(background=True), family=False
         )
         super().fade(darkness, family)
         return self
@@ -370,6 +366,8 @@ class VMobject(Mobject):
             width = self.background_stroke_width
         else:
             width = self.stroke_width
+            if isinstance(width, str):
+                width = int(width)
         return max(0, width)
 
     def get_stroke_opacity(self, background=False):
@@ -388,7 +386,26 @@ class VMobject(Mobject):
             return self.get_stroke_color()
         return self.get_fill_color()
 
-    def set_sheen_direction(self, direction, family=True):
+    def set_sheen_direction(self, direction: np.ndarray, family=True):
+        """Sets the direction of the applied sheen.
+
+        Parameters
+        ----------
+        direction : :class:`numpy.ndarray`, optional
+            Direction from where the gradient is applied.
+
+        Examples
+        --------
+        Normal usage::
+
+            Circle().set_sheen_direction(UP)
+
+        See Also
+        --------
+        :meth:`~.VMobject.set_sheen`
+        :meth:`~.VMobject.rotate_sheen_direction`
+        """
+
         direction = np.array(direction)
         if family:
             for submob in self.get_family():
@@ -397,7 +414,58 @@ class VMobject(Mobject):
             self.sheen_direction = direction
         return self
 
-    def set_sheen(self, factor, direction=None, family=True):
+    def rotate_sheen_direction(self, angle: np.ndarray, axis: float = OUT, family=True):
+        """Rotates the direction of the applied sheen.
+
+        Parameters
+        ----------
+        angle : :class:`float`
+            Angle by which the direction of sheen is rotated.
+        axis : :class:`numpy.ndarray`
+            Axis of rotation.
+
+        Examples
+        --------
+        Normal usage::
+
+            Circle().set_sheen_direction(UP).rotate_sheen_direction(PI)
+
+        See Also
+        --------
+        :meth:`~.VMobject.set_sheen_direction`
+        """
+        if family:
+            for submob in self.get_family():
+                submob.sheen_direction = rotate_vector(
+                    submob.sheen_direction, angle, axis
+                )
+        else:
+            self.sheen_direction = rotate_vector(self.sheen_direction, angle, axis)
+        return self
+
+    def set_sheen(self, factor, direction: np.ndarray = None, family=True):
+        """Applies a color gradient from a direction.
+
+        Parameters
+        ----------
+        factor : :class:`float`
+            The extent of lustre/gradient to apply. If negative, the gradient
+            starts from black, if positive the gradient starts from white and
+            changes to the current color.
+        direction : :class:`numpy.ndarray`, optional
+            Direction from where the gradient is applied.
+
+        Examples
+        --------
+        .. manim:: SetSheen
+            :save_last_frame:
+
+            class SetSheen(Scene):
+                def construct(self):
+                    circle = Circle(fill_opacity=1).set_sheen(-0.3, DR)
+                    self.add(circle)
+        """
+
         if family:
             for submob in self.submobjects:
                 submob.set_sheen(factor, direction, family)
@@ -430,14 +498,14 @@ class VMobject(Mobject):
             offset = np.dot(bases, direction)
             return (c - offset, c + offset)
 
-    def color_using_background_image(self, background_image: Union[Image.Image, str]):
+    def color_using_background_image(self, background_image: Union[Image, str]):
         self.background_image = background_image
         self.set_color(WHITE)
         for submob in self.submobjects:
             submob.color_using_background_image(background_image)
         return self
 
-    def get_background_image(self) -> Union[Image.Image, str]:
+    def get_background_image(self) -> Union[Image, str]:
         return self.background_image
 
     def match_background_image(self, vmobject):
@@ -468,7 +536,7 @@ class VMobject(Mobject):
     ) -> "VMobject":
         """Given two sets of anchors and handles, process them to set them as anchors and handles of the VMobject.
 
-        anchors1[i], handles1[i], handles2[i] and anchors2[i] define the i-th bezier curve of the vmobject. There are four hardcoded paramaters and this is a problem as it makes the number of points per cubic curve unchangeable from 4. (two anchors and two handles).
+        anchors1[i], handles1[i], handles2[i] and anchors2[i] define the i-th bezier curve of the vmobject. There are four hardcoded parameters and this is a problem as it makes the number of points per cubic curve unchangeable from 4. (two anchors and two handles).
 
         Returns
         -------
@@ -511,7 +579,7 @@ class VMobject(Mobject):
     ) -> None:
         """Add cubic bezier curve to the path.
 
-        NOTE : the first anchor is not a paramater as by default the end of the last sub-path!
+        NOTE : the first anchor is not a parameter as by default the end of the last sub-path!
 
         Parameters
         ----------
@@ -717,6 +785,17 @@ class VMobject(Mobject):
             self.make_smooth()
         return self
 
+    def rotate(
+        self,
+        angle: float,
+        axis: np.ndarray = OUT,
+        about_point: Optional[Sequence[float]] = None,
+        **kwargs,
+    ):
+        self.rotate_sheen_direction(angle, axis)
+        super().rotate(angle, axis, about_point, **kwargs)
+        return self
+
     def scale_handle_to_anchor_distances(self, factor: float) -> "VMobject":
         """If the distance between a given handle point H and its associated
         anchor point A is d, then it changes H to be a distances factor*d
@@ -816,8 +895,8 @@ class VMobject(Mobject):
 
         The algorithm every bezier tuple (anchors and handles) in ``self.points`` (by regrouping each n elements, where
         n is the number of points per cubic curve)), and evaluate the relation between two anchors with filter_func.
-        NOTE : The filter_func takes an int n as paramater, and will evaluate the relation between points[n] and points[n - 1]. This should probably be changed so
-        the function takes two points as paramters.
+        NOTE : The filter_func takes an int n as parameter, and will evaluate the relation between points[n] and points[n - 1]. This should probably be changed so
+        the function takes two points as parameters.
 
         Parameters
         ----------
@@ -1069,14 +1148,7 @@ class VMobject(Mobject):
         if self.points.shape[0] == 1:
             return self.points
         return np.array(
-            list(
-                it.chain(
-                    *zip(
-                        self.get_start_anchors(),
-                        self.get_end_anchors(),
-                    )
-                )
-            )
+            list(it.chain(*zip(self.get_start_anchors(), self.get_end_anchors())))
         )
 
     def get_points_defining_boundary(self):
@@ -1396,7 +1468,7 @@ class VMobject(Mobject):
         return self
 
 
-class VGroup(VMobject):
+class VGroup(VMobject, metaclass=ConvertToOpenGL):
     """A group of vectorized mobjects.
 
     This can be used to group multiple :class:`~.VMobject` instances together
@@ -1435,7 +1507,7 @@ class VGroup(VMobject):
 
         class ArcShapeIris(Scene):
             def construct(self):
-                colors = [DARK_BLUE, DARK_BROWN, BLUE_E, BLUE_D, BLUE_A, TEAL_B, GREEN_B, YELLOW_E]
+                colors = [DARK_BROWN, BLUE_E, BLUE_D, BLUE_A, TEAL_B, GREEN_B, YELLOW_E]
                 radius = [1 + rad * 0.1 for rad in range(len(colors))]
 
                 circles_group = VGroup()
@@ -1448,7 +1520,7 @@ class VGroup(VMobject):
     """
 
     def __init__(self, *vmobjects, **kwargs):
-        VMobject.__init__(self, **kwargs)
+        super().__init__(**kwargs)
         self.add(*vmobjects)
 
     def __repr__(self):
@@ -1513,7 +1585,7 @@ class VGroup(VMobject):
                         (gr-circle_red).animate.shift(RIGHT)
                     )
         """
-        if not all(isinstance(m, VMobject) for m in vmobjects):
+        if not all(isinstance(m, (VMobject, OpenGLVMobject)) for m in vmobjects):
             raise TypeError("All submobjects must be of type VMobject")
         return super().add(*vmobjects)
 
@@ -1531,6 +1603,32 @@ class VGroup(VMobject):
     def __isub__(self, vmobject):
         return self.remove(vmobject)
 
+    def __setitem__(self, key: int, value: Union[VMobject, typing.Sequence[VMobject]]):
+        """Override the [] operator for item assignment.
+
+        Parameters
+        ----------
+        key
+            The index of the submobject to be assigned
+        value
+            The vmobject value to assign to the key
+
+        Returns
+        -------
+        None
+
+        Examples
+        --------
+        Normal usage::
+
+            >>> vgroup = VGroup(VMobject())
+            >>> new_obj = VMobject()
+            >>> vgroup[0] = new_obj
+        """
+        if not all(isinstance(m, (VMobject, OpenGLVMobject)) for m in value):
+            raise TypeError("All submobjects must be of type VMobject")
+        self.submobjects[key] = value
+
 
 class VDict(VMobject):
     """A VGroup-like class, also offering submobject access by
@@ -1609,7 +1707,7 @@ class VDict(VMobject):
                 self.play(FadeOut(my_dict["c"]))
                 self.wait()
 
-                self.play(FadeOutAndShift(my_dict["r"], DOWN))
+                self.play(FadeOut(my_dict["r"], shift=DOWN))
                 self.wait()
 
                 # you can also make a VDict from an existing dict of mobjects
@@ -1858,7 +1956,7 @@ class VDict(VMobject):
         super().add(value)
 
 
-class VectorizedPoint(VMobject):
+class VectorizedPoint(VMobject, metaclass=ConvertToOpenGL):
     def __init__(
         self,
         location=ORIGIN,
@@ -1871,8 +1969,7 @@ class VectorizedPoint(VMobject):
     ):
         self.artificial_width = artificial_width
         self.artificial_height = artificial_height
-        VMobject.__init__(
-            self,
+        super().__init__(
             color=color,
             fill_opacity=fill_opacity,
             stroke_width=stroke_width,
@@ -1880,11 +1977,13 @@ class VectorizedPoint(VMobject):
         )
         self.set_points(np.array([location]))
 
-    @VMobject.width.getter
+    basecls = OpenGLVMobject if config.renderer == "opengl" else VMobject
+
+    @basecls.width.getter
     def width(self):
         return self.artificial_width
 
-    @VMobject.height.getter
+    @basecls.height.getter
     def height(self):
         return self.artificial_height
 
@@ -1922,13 +2021,13 @@ class CurvesAsSubmobjects(VGroup):
             self.add(part)
 
 
-class DashedVMobject(VMobject):
+class DashedVMobject(VMobject, metaclass=ConvertToOpenGL):
     def __init__(
         self, vmobject, num_dashes=15, positive_space_ratio=0.5, color=WHITE, **kwargs
     ):
         self.num_dashes = num_dashes
         self.positive_space_ratio = positive_space_ratio
-        VMobject.__init__(self, color=color, **kwargs)
+        super().__init__(color=color, **kwargs)
         ps_ratio = self.positive_space_ratio
         if num_dashes > 0:
             # End points of the unit interval for division
@@ -1957,4 +2056,7 @@ class DashedVMobject(VMobject):
             )
         # Family is already taken care of by get_subcurve
         # implementation
-        self.match_style(vmobject, family=False)
+        if config.renderer == "opengl":
+            self.match_style(vmobject, recurse=False)
+        else:
+            self.match_style(vmobject, family=False)
