@@ -8,7 +8,6 @@ import copy
 import inspect
 import platform
 import random
-import string
 import threading
 import types
 import warnings
@@ -24,9 +23,10 @@ from ..animation.animation import Animation, Wait, prepare_animation
 from ..camera.camera import Camera
 from ..constants import *
 from ..container import Container
-from ..mobject.mobject import Mobject, _AnimationBuilder
-from ..mobject.opengl_mobject import OpenGLMobject, OpenGLPoint
+from ..mobject.opengl_mobject import OpenGLPoint
 from ..renderer.cairo_renderer import CairoRenderer
+from ..renderer.shader import Mesh
+from ..utils import opengl, space_ops
 from ..utils.exceptions import EndSceneEarlyException, RerunSceneException
 from ..utils.family import extract_mobject_family_members
 from ..utils.family_ops import restructure_list_to_exclude_certain_family_members
@@ -99,6 +99,8 @@ class Scene(Container):
         self.last_t = None
         self.queue = Queue()
         self.skip_animation_preview = False
+        self.meshes = []
+        self.camera_target = ORIGIN
 
         if config.renderer == "opengl":
             # Items associated with interaction
@@ -305,6 +307,10 @@ class Scene(Container):
         for mobject in self.mobjects:
             mobject.update(dt)
 
+    def update_meshes(self, dt):
+        for mesh in self.meshes:
+            mesh.update(dt)
+
     def should_update_mobjects(self):
         """
         Returns True if any mobject in Scene is being updated
@@ -376,9 +382,17 @@ class Scene(Container):
 
         """
         if config.renderer == "opengl":
-            new_mobjects = mobjects
+            new_mobjects = []
+            new_meshes = []
+            for mobject_or_mesh in mobjects:
+                if isinstance(mobject_or_mesh, Mesh):
+                    new_meshes.append(mobject_or_mesh)
+                else:
+                    new_mobjects.append(mobject_or_mesh)
             self.remove(*new_mobjects)
             self.mobjects += new_mobjects
+            self.remove(*new_meshes)
+            self.meshes += new_meshes
         else:
             mobjects = [*mobjects, *self.foreground_mobjects]
             self.restructure_mobjects(to_remove=mobjects)
@@ -413,10 +427,19 @@ class Scene(Container):
             The mobjects to remove.
         """
         if config.renderer == "opengl":
-            mobjects_to_remove = mobjects
+            mobjects_to_remove = []
+            meshes_to_remove = set()
+            for mobject_or_mesh in mobjects:
+                if isinstance(mobject_or_mesh, Mesh):
+                    meshes_to_remove.add(mobject_or_mesh)
+                else:
+                    mobjects_to_remove.append(mobject_or_mesh)
             self.mobjects = restructure_list_to_exclude_certain_family_members(
                 self.mobjects, mobjects_to_remove
             )
+            self.meshes = list(
+                filter(lambda mesh: mesh not in set(meshes_to_remove), self.meshes)
+            )
             return self
         else:
             for list_name in "mobjects", "foreground_mobjects":
@@ -902,7 +925,7 @@ class Scene(Container):
             animation.begin()
 
     def is_current_animation_frozen_frame(self) -> bool:
-        """Returns wether the current animation produces a static frame (generally a Wait)."""
+        """Returns whether the current animation produces a static frame (generally a Wait)."""
         return (
             isinstance(self.animations[0], Wait)
             and len(self.animations) == 1
@@ -967,7 +990,7 @@ class Scene(Container):
             namespace["rerun"] = embedded_rerun
 
             shell(local_ns=namespace)
-            self.queue.put(("exit", [], {}))
+            self.queue.put(("exit_keyboard", [], {}))
 
         def get_embedded_method(method_name):
             return lambda *args, **kwargs: self.queue.put((method_name, args, kwargs))
@@ -1036,6 +1059,7 @@ class Scene(Container):
                 dt = 1 / config["frame_rate"]
                 self.renderer.render(self, dt, self.moving_mobjects)
                 self.update_mobjects(dt)
+                self.update_meshes(dt)
 
         # Join the keyboard thread if necessary.
         if shell is not None and keyboard_thread_needs_join:
@@ -1068,7 +1092,7 @@ class Scene(Container):
         )
 
         # Use the locals of the caller as the local namespace
-        # once embeded, and add a few custom shortcuts.
+        # once embedded, and add a few custom shortcuts.
         local_ns = inspect.currentframe().f_back.f_locals
         # local_ns["touch"] = self.interact
         for method in (
@@ -1095,6 +1119,7 @@ class Scene(Container):
             alpha = t / animation.run_time
             animation.interpolate(alpha)
         self.update_mobjects(dt)
+        self.update_meshes(dt)
 
     def add_sound(self, sound_file, time_offset=0, gain=None, **kwargs):
         """
@@ -1147,16 +1172,9 @@ class Scene(Container):
             self.camera.shift(shift)
 
     def on_mouse_scroll(self, point, offset):
-        if CTRL_VALUE in self.renderer.pressed_keys:
-            factor = 1 + np.arctan(-20 * offset[1])
-            self.camera.scale(factor, about_point=point)
-
-        transform = self.camera.inverse_rotation_matrix
-        shift = np.dot(np.transpose(transform), offset)
-        if SHIFT_VALUE in self.renderer.pressed_keys:
-            self.camera.shift(20.0 * np.array(rotate_vector(shift, PI / 2)))
-        else:
-            self.camera.shift(20.0 * shift)
+        factor = 1 + np.arctan(-2.1 * offset[1])
+        self.camera.scale(factor, about_point=self.camera_target)
+        self.mouse_scroll_orbit_controls(point, offset)
 
     def on_key_press(self, symbol, modifiers):
         try:
@@ -1167,6 +1185,7 @@ class Scene(Container):
 
         if char == "r":
             self.camera.to_default_state()
+            self.camera_target = np.array([0, 0, 0], dtype=np.float32)
         elif char == "q":
             self.quit_interaction = True
 
@@ -1175,5 +1194,90 @@ class Scene(Container):
 
     def on_mouse_drag(self, point, d_point, buttons, modifiers):
         self.mouse_drag_point.move_to(point)
-        self.camera.increment_theta(-d_point[0])
-        self.camera.increment_phi(d_point[1])
+        if buttons == 1:
+            self.camera.increment_theta(-d_point[0])
+            self.camera.increment_phi(d_point[1])
+        elif buttons == 4:
+            camera_x_axis = self.camera.model_matrix[:3, 0]
+            horizontal_shift_vector = -d_point[0] * camera_x_axis
+            vertical_shift_vector = -d_point[1] * np.cross(OUT, camera_x_axis)
+            total_shift_vector = horizontal_shift_vector + vertical_shift_vector
+            self.camera.shift(1.1 * total_shift_vector)
+
+        self.mouse_drag_orbit_controls(point, d_point, buttons, modifiers)
+
+    def mouse_scroll_orbit_controls(self, point, offset):
+        camera_to_target = self.camera_target - self.camera.get_position()
+        camera_to_target *= np.sign(offset[1])
+        shift_vector = 0.01 * camera_to_target
+        self.camera.model_matrix = (
+            opengl.translation_matrix(*shift_vector) @ self.camera.model_matrix
+        )
+
+    def mouse_drag_orbit_controls(self, point, d_point, buttons, modifiers):
+        # Left click drag.
+        if buttons == 1:
+            # Translate to target the origin and rotate around the z axis.
+            self.camera.model_matrix = (
+                opengl.rotation_matrix(z=-d_point[0])
+                @ opengl.translation_matrix(*-self.camera_target)
+                @ self.camera.model_matrix
+            )
+
+            # Rotation off of the z axis.
+            camera_position = self.camera.get_position()
+            camera_y_axis = self.camera.model_matrix[:3, 1]
+            axis_of_rotation = space_ops.normalize(
+                np.cross(camera_y_axis, camera_position)
+            )
+            rotation_matrix = space_ops.rotation_matrix(
+                d_point[1], axis_of_rotation, homogeneous=True
+            )
+
+            maximum_polar_angle = PI / 2
+            minimum_polar_angle = -PI / 2
+
+            potential_camera_model_matrix = rotation_matrix @ self.camera.model_matrix
+            potential_camera_location = potential_camera_model_matrix[:3, 3]
+            potential_camera_y_axis = potential_camera_model_matrix[:3, 1]
+            sign = (
+                np.sign(potential_camera_y_axis[2])
+                if potential_camera_y_axis[2] != 0
+                else 1
+            )
+            potential_polar_angle = sign * np.arccos(
+                potential_camera_location[2] / np.linalg.norm(potential_camera_location)
+            )
+            if minimum_polar_angle <= potential_polar_angle <= maximum_polar_angle:
+                self.camera.model_matrix = potential_camera_model_matrix
+            else:
+                sign = np.sign(camera_y_axis[2]) if camera_y_axis[2] != 0 else 1
+                current_polar_angle = sign * np.arccos(
+                    camera_position[2] / np.linalg.norm(camera_position)
+                )
+                if potential_polar_angle > maximum_polar_angle:
+                    polar_angle_delta = maximum_polar_angle - current_polar_angle
+                else:
+                    polar_angle_delta = minimum_polar_angle - current_polar_angle
+                rotation_matrix = space_ops.rotation_matrix(
+                    polar_angle_delta, axis_of_rotation, homogeneous=True
+                )
+                self.camera.model_matrix = rotation_matrix @ self.camera.model_matrix
+
+            # Translate to target the original target.
+            self.camera.model_matrix = (
+                opengl.translation_matrix(*self.camera_target)
+                @ self.camera.model_matrix
+            )
+        # Right click drag.
+        elif buttons == 4:
+            camera_x_axis = self.camera.model_matrix[:3, 0]
+            horizontal_shift_vector = -d_point[0] * camera_x_axis
+            vertical_shift_vector = -d_point[1] * np.cross(OUT, camera_x_axis)
+            total_shift_vector = horizontal_shift_vector + vertical_shift_vector
+
+            self.camera.model_matrix = (
+                opengl.translation_matrix(*total_shift_vector)
+                @ self.camera.model_matrix
+            )
+            self.camera_target += total_shift_vector
