@@ -3,22 +3,27 @@
 __all__ = ["SceneFileWriter"]
 
 
-import numpy as np
-from pydub import AudioSegment
+import datetime
+import os
 import shutil
 import subprocess
-import os
-from time import sleep
-import datetime
-from PIL import Image
 from pathlib import Path
+from time import sleep
+
+import numpy as np
+from PIL import Image
+from pydub import AudioSegment
 
 from manim import __version__
+
 from .. import config, logger
 from ..constants import FFMPEG_BIN, GIF_FILE_EXTENSION
-from ..utils.file_ops import guarantee_existence
-from ..utils.file_ops import add_extension_if_not_present, add_version_before_extension
-from ..utils.file_ops import modify_atime
+from ..utils.file_ops import (
+    add_extension_if_not_present,
+    add_version_before_extension,
+    guarantee_existence,
+    modify_atime,
+)
 from ..utils.sounds import get_full_sound_file_path
 
 
@@ -73,14 +78,13 @@ class SceneFileWriter(object):
         else:
             default_name = Path(scene_name)
 
-        if config["save_last_frame"] or config["save_pngs"]:
-            if config["media_dir"]:
-                image_dir = guarantee_existence(
-                    config.get_dir("images_dir", module_name=module_name)
-                )
-            self.image_file_path = os.path.join(
-                image_dir, add_extension_if_not_present(default_name, ".png")
+        if config["media_dir"]:
+            image_dir = guarantee_existence(
+                config.get_dir("images_dir", module_name=module_name)
             )
+        self.image_file_path = os.path.join(
+            image_dir, add_extension_if_not_present(default_name, ".png")
+        )
 
         if config["write_to_movie"]:
             movie_dir = guarantee_existence(
@@ -93,7 +97,7 @@ class SceneFileWriter(object):
                     default_name, config["movie_file_extension"]
                 ),
             )
-            if config["save_as_gif"]:
+            if config["format"] == "gif":
                 self.gif_file_path = os.path.join(
                     movie_dir,
                     add_extension_if_not_present(default_name, GIF_FILE_EXTENSION),
@@ -274,7 +278,7 @@ class SceneFileWriter(object):
         frame : np.array
             Pixel array of the frame.
         """
-        if config["use_opengl_renderer"]:
+        if config.renderer == "opengl":
             renderer = frame_or_renderer
             self.writing_process.stdin.write(
                 renderer.get_raw_frame_buffer_object_data()
@@ -283,7 +287,7 @@ class SceneFileWriter(object):
             frame = frame_or_renderer
             if config["write_to_movie"]:
                 self.writing_process.stdin.write(frame.tobytes())
-            if config["save_pngs"]:
+            if config["format"] == "png":
                 path, extension = os.path.splitext(self.image_file_path)
                 Image.fromarray(frame).save(f"{path}{self.frame_count}{extension}")
                 self.frame_count += 1
@@ -351,7 +355,9 @@ class SceneFileWriter(object):
         self.partial_movie_file_path = file_path
 
         fps = config["frame_rate"]
-        if config["use_opengl_renderer"]:
+        if fps == int(fps):  # fps is integer
+            fps = int(fps)
+        if config.renderer == "opengl":
             width, height = self.renderer.get_pixel_shape()
         else:
             height = config["pixel_height"]
@@ -376,7 +382,7 @@ class SceneFileWriter(object):
             "-metadata",
             f"comment=Rendered with Manim Community v{__version__}",
         ]
-        if config["use_opengl_renderer"]:
+        if config.renderer == "opengl":
             command += ["-vf", "vflip"]
         if config["transparent"]:
             command += ["-vcodec", "qtrle"]
@@ -468,10 +474,10 @@ class SceneFileWriter(object):
             "-nostdin",
         ]
 
-        if config["write_to_movie"] and not config["save_as_gif"]:
+        if config["write_to_movie"] and not config["format"] == "gif":
             commands += ["-c", "copy", movie_file_path]
 
-        if config["save_as_gif"]:
+        if config["format"] == "gif":
             if not config["output_file"]:
                 self.gif_file_path = str(
                     add_version_before_extension(self.gif_file_path)
