@@ -19,6 +19,7 @@ __all__ = [
     "cross",
     "get_unit_normal",
     "compass_directions",
+    "regular_vertices",
     "complex_to_R3",
     "R3_to_complex",
     "complex_func_to_R3_func",
@@ -35,33 +36,42 @@ __all__ = [
 import itertools as it
 import math
 from functools import reduce
+from typing import List, Optional, Sequence, Tuple, Union
 
 import numpy as np
 from mapbox_earcut import triangulate_float32 as earcut
 
 from .. import config
 from ..constants import DOWN, OUT, PI, RIGHT, TAU
+from ..utils.deprecation import deprecated
 from ..utils.iterables import adjacent_pairs
-from ..utils.simple_functions import fdiv
 
 
+@deprecated(since="v0.6.0", until="v0.8.0", replacement="np.linalg.norm")
 def get_norm(vect):
-    logger.warning(
-        "get_norm has been deprecated and will be removed in a future release."
-        "Use np.linalg.norm instead."
-    )
     return np.linalg.norm(vect)
 
 
-def norm_squared(v):
-    return np.linalg.dot(v, v)
+def norm_squared(v: float) -> float:
+    return np.dot(v, v)
 
 
 # Quaternions
 # TODO, implement quaternion type
 
 
-def quaternion_mult(*quats):
+def quaternion_mult(
+    *quats: Sequence[float],
+) -> Union[np.ndarray, List[Union[float, np.ndarray]]]:
+    """Gets the Hamilton product of the quaternions provided.
+    For more information, check `this Wikipedia page
+    <https://en.wikipedia.org/wiki/Quaternion>`_.
+
+    Returns
+    -------
+    Union[np.ndarray, List[Union[float, np.ndarray]]]
+        Returns a list of product of two quaternions.
+    """
     if config.renderer == "opengl":
         if len(quats) == 0:
             return [1, 0, 0, 0]
@@ -92,7 +102,27 @@ def quaternion_mult(*quats):
         )
 
 
-def quaternion_from_angle_axis(angle, axis, axis_normalized=False):
+def quaternion_from_angle_axis(
+    angle: float, axis: np.ndarray, axis_normalized: bool = False
+) -> List[float]:
+    """Gets a quaternion from an angle and an axis.
+    For more information, check `this Wikipedia page
+    <https://en.wikipedia.org/wiki/Conversion_between_quaternions_and_Euler_angles>`_.
+
+    Parameters
+    ----------
+    angle
+        The angle for the quaternion.
+    axis
+        The axis for the quaternion
+    axis_normalized : bool, optional
+        Checks whether the axis is normalized, by default False
+
+    Returns
+    -------
+    List[float]
+        Gives back a quaternion from the angle and axis
+    """
     if config.renderer == "opengl":
         if not axis_normalized:
             axis = normalize(axis)
@@ -101,7 +131,19 @@ def quaternion_from_angle_axis(angle, axis, axis_normalized=False):
         return np.append(np.cos(angle / 2), np.sin(angle / 2) * normalize(axis))
 
 
-def angle_axis_from_quaternion(quaternion):
+def angle_axis_from_quaternion(quaternion: Sequence[float]) -> Sequence[float]:
+    """Gets angle and axis from a quaternion.
+
+    Parameters
+    ----------
+    quaternion
+        The quaternion from which we get the angle and axis.
+
+    Returns
+    -------
+    Sequence[float]
+        Gives the angle and axis
+    """
     axis = normalize(quaternion[1:], fall_back=np.array([1, 0, 0]))
     angle = 2 * np.arccos(quaternion[0])
     if angle > TAU / 2:
@@ -109,13 +151,47 @@ def angle_axis_from_quaternion(quaternion):
     return angle, axis
 
 
-def quaternion_conjugate(quaternion):
+def quaternion_conjugate(quaternion: Sequence[float]) -> np.ndarray:
+    """Used for finding the conjugate of the quaternion
+
+    Parameters
+    ----------
+    quaternion
+        The quaternion for which you want to find the conjugate for.
+
+    Returns
+    -------
+    np.ndarray
+        The conjugate of the quaternion.
+    """
     result = np.array(quaternion)
     result[1:] *= -1
     return result
 
 
-def rotate_vector(vector, angle, axis=OUT):
+def rotate_vector(vector: np.ndarray, angle: int, axis: np.ndarray = OUT) -> np.ndarray:
+    """Function for rotating a vector.
+
+    Parameters
+    ----------
+    vector
+        The vector to be rotated.
+    angle
+        The angle to be rotated by.
+    axis
+        The axis to be rotated, by default OUT
+
+    Returns
+    -------
+    np.ndarray
+        The rotated vector with provided angle and axis.
+
+    Raises
+    ------
+    ValueError
+        If vector is not of dimension 2 or 3.
+    """
+
     if len(vector) == 2:
         # Use complex numbers...because why not
         z = complex(*vector) * np.exp(complex(0, angle))
@@ -130,13 +206,28 @@ def rotate_vector(vector, angle, axis=OUT):
         raise ValueError("vector must be of dimension 2 or 3")
 
 
-def thick_diagonal(dim, thickness=2):
+def thick_diagonal(dim: int, thickness=2) -> np.ndarray:
     row_indices = np.arange(dim).repeat(dim).reshape((dim, dim))
     col_indices = np.transpose(row_indices)
     return (np.abs(row_indices - col_indices) < thickness).astype("uint8")
 
 
-def rotation_matrix_transpose_from_quaternion(quat):
+def rotation_matrix_transpose_from_quaternion(quat: np.ndarray) -> List[np.ndarray]:
+    """Converts the quaternion, quat, to an equivalent rotation matrix representation.
+    For more information, check `this page
+    <https://in.mathworks.com/help/driving/ref/quaternion.rotmat.html>`_.
+
+    Parameters
+    ----------
+    quat
+        The quaternion which is to be converted.
+
+    Returns
+    -------
+    List[np.ndarray]
+        Gives back the Rotation matrix representation, returned as a 3-by-3
+        matrix or 3-by-3-by-N multidimensional array.
+    """
     quat_inv = quaternion_conjugate(quat)
     return [
         quaternion_mult(quat, [0, *basis], quat_inv)[1:]
@@ -148,11 +239,11 @@ def rotation_matrix_transpose_from_quaternion(quat):
     ]
 
 
-def rotation_matrix_from_quaternion(quat):
+def rotation_matrix_from_quaternion(quat: np.ndarray) -> np.ndarray:
     return np.transpose(rotation_matrix_transpose_from_quaternion(quat))
 
 
-def rotation_matrix_transpose(angle, axis):
+def rotation_matrix_transpose(angle: float, axis: np.ndarray) -> np.ndarray:
     if axis[0] == 0 and axis[1] == 0:
         # axis = [0, 0, z] case is common enough it's worth
         # having a shortcut
@@ -168,17 +259,37 @@ def rotation_matrix_transpose(angle, axis):
     return rotation_matrix_transpose_from_quaternion(quat)
 
 
-def rotation_matrix(angle, axis):
+def rotation_matrix(
+    angle: float, axis: np.ndarray, homogeneous: bool = False
+) -> np.ndarray:
     """
     Rotation in R^3 about a specified axis of rotation.
     """
     about_z = rotation_about_z(angle)
     z_to_axis = z_to_vector(axis)
     axis_to_z = np.linalg.inv(z_to_axis)
-    return reduce(np.dot, [z_to_axis, about_z, axis_to_z])
+    inhomogeneous_rotation_matrix = reduce(np.dot, [z_to_axis, about_z, axis_to_z])
+    if not homogeneous:
+        return inhomogeneous_rotation_matrix
+    else:
+        rotation_matrix = np.eye(4)
+        rotation_matrix[:3, :3] = inhomogeneous_rotation_matrix
+        return rotation_matrix
 
 
-def rotation_about_z(angle):
+def rotation_about_z(angle: float) -> List[List[float]]:
+    """Returns a rotation matrix for a given angle.
+
+    Parameters
+    ----------
+    angle : float
+        Angle for the rotation matrix.
+
+    Returns
+    -------
+    List[float]
+        Gives back the rotated matrix.
+    """
     return [
         [np.cos(angle), -np.sin(angle), 0],
         [np.sin(angle), np.cos(angle), 0],
@@ -186,7 +297,7 @@ def rotation_about_z(angle):
     ]
 
 
-def z_to_vector(vector):
+def z_to_vector(vector: np.ndarray) -> np.ndarray:
     """
     Returns some matrix in SO(3) which takes the z-axis to the
     (normalized) vector provided as an argument
@@ -210,17 +321,23 @@ def z_to_vector(vector):
     return np.dot(rotation_about_z(theta), phi_down)
 
 
+@deprecated(since="v0.6.0", until="v0.8.0", replacement="angle_between_vectors")
 def angle_between(v1, v2):
-    logger.warning(
-        "angle_between has been deprecated and will be removed in a future release."
-        "Use angle_between_vectors instead."
-    )
     return np.arccos(np.dot(v1 / np.linalg.norm(v1), v2 / np.linalg.norm(v2)))
 
 
-def angle_of_vector(vector):
-    """
-    Returns polar coordinate theta when vector is project on xy plane
+def angle_of_vector(vector: Sequence[float]) -> float:
+    """Returns polar coordinate theta when vector is projected on xy plane.
+
+    Parameters
+    ----------
+    vector
+        The vector to find the angle for.
+
+    Returns
+    -------
+    float
+        The angle of the vector projected.
     """
     if config.renderer == "opengl":
         return np.angle(complex(*vector[:2]))
@@ -231,10 +348,21 @@ def angle_of_vector(vector):
         return np.angle(complex(*vector[:2]))
 
 
-def angle_between_vectors(v1, v2):
-    """
-    Returns the angle between two 3D vectors.
-    This angle will always be btw 0 and pi
+def angle_between_vectors(v1: np.ndarray, v2: np.ndarray) -> np.ndarray:
+    """Returns the angle between two vectors.
+    This angle will always be between 0 and pi
+
+    Parameters
+    ----------
+    v1
+        The first vector.
+    v2
+        The second vector.
+
+    Returns
+    -------
+    np.ndarray
+        The angle between the vectors.
     """
     if config["renderer"] == "opengl":
         diff = (angle_of_vector(v2) - angle_of_vector(v1)) % TAU
@@ -246,12 +374,26 @@ def angle_between_vectors(v1, v2):
         )
 
 
-def project_along_vector(point, vector):
+def project_along_vector(point: float, vector: np.ndarray) -> np.ndarray:
+    """Projects a vector along a point.
+
+    Parameters
+    ----------
+    point
+        The point to be project from.
+    vector
+        The vector which has to projected.
+
+    Returns
+    -------
+    np.ndarray
+        A dot product of the point and vector.
+    """
     matrix = np.identity(3) - np.outer(vector, vector)
     return np.dot(point, matrix.T)
 
 
-def normalize(vect, fall_back=None):
+def normalize(vect: Union[np.ndarray, Tuple[float]], fall_back=None) -> np.ndarray:
     norm = np.linalg.norm(vect)
     if norm > 0:
         return np.array(vect) / norm
@@ -262,7 +404,21 @@ def normalize(vect, fall_back=None):
             return np.zeros(len(vect))
 
 
-def normalize_along_axis(array, axis, fall_back=None):
+def normalize_along_axis(array: np.ndarray, axis: np.ndarray) -> np.ndarray:
+    """Normalizes an array with the provided axis.
+
+    Parameters
+    ----------
+    array
+        The array which has to be normalized.
+    axis
+        The axis to be normalized to.
+
+    Returns
+    -------
+    np.ndarray
+        Array which has been normalized according to the axis.
+    """
     norms = np.sqrt((array * array).sum(axis))
     norms[norms == 0] = 1
     buffed_norms = np.repeat(norms, array.shape[axis]).reshape(array.shape)
@@ -270,15 +426,28 @@ def normalize_along_axis(array, axis, fall_back=None):
     return array
 
 
+@deprecated(since="v0.6.0", until="v0.8.0", replacement="np.cross")
 def cross(v1, v2):
-    logger.warning(
-        "cross has been deprecated and will be removed in a future release."
-        "Use np.cross instead."
-    )
     return np.cross(v1, v2)
 
 
-def get_unit_normal(v1, v2, tol=1e-6):
+def get_unit_normal(v1: np.ndarray, v2: np.ndarray, tol: float = 1e-6) -> np.ndarray:
+    """Gets the unit normal of the vectors.
+
+    Parameters
+    ----------
+    v1
+        The first vector.
+    v2
+        The second vector
+    tol
+        [description], by default 1e-6
+
+    Returns
+    -------
+    np.ndarray
+        The normal of the two vectors.
+    """
     if config.renderer == "opengl":
         v1 = normalize(v1)
         v2 = normalize(v2)
@@ -299,16 +468,67 @@ def get_unit_normal(v1, v2, tol=1e-6):
 ###
 
 
-def compass_directions(n=4, start_vect=RIGHT):
+def compass_directions(n: int = 4, start_vect: np.ndarray = RIGHT) -> np.ndarray:
+    """Finds the cardinal directions using tau.
+
+    Parameters
+    ----------
+    n
+        The amount to be rotated, by default 4
+    start_vect
+        The direction for the angle to start with, by default RIGHT
+
+    Returns
+    -------
+    np.ndarray
+        The angle which has been rotated.
+    """
     angle = TAU / n
     return np.array([rotate_vector(start_vect, k * angle) for k in range(n)])
 
 
-def complex_to_R3(complex_num):
+def regular_vertices(
+    n: int, *, radius: float = 1, start_angle: Optional[float] = None
+) -> Tuple[np.ndarray, float]:
+    """Generates regularly spaced vertices around a circle centered at the origin.
+
+    Parameters
+    ----------
+    n
+        The number of vertices
+    radius
+        The radius of the circle that the vertices are placed on.
+    start_angle
+        The angle the vertices start at.
+
+        If unspecified, for even ``n`` values, ``0`` will be used.
+        For odd ``n`` values, 90 degrees is used.
+
+    Returns
+    -------
+    vertices : :class:`numpy.ndarray`
+        The regularly spaced vertices.
+    start_angle : :class:`float`
+        The angle the vertices start at.
+    """
+
+    if start_angle is None:
+        if n % 2 == 0:
+            start_angle = 0
+        else:
+            start_angle = TAU / 4
+
+    start_vector = rotate_vector(RIGHT * radius, start_angle)
+    vertices = compass_directions(n, start_vector)
+
+    return vertices, start_angle
+
+
+def complex_to_R3(complex_num: complex) -> np.ndarray:
     return np.array((complex_num.real, complex_num.imag, 0))
 
 
-def R3_to_complex(point):
+def R3_to_complex(point: Sequence[float]) -> np.ndarray:
     return complex(*point[:2])
 
 
@@ -316,20 +536,63 @@ def complex_func_to_R3_func(complex_func):
     return lambda p: complex_to_R3(complex_func(R3_to_complex(p)))
 
 
-def center_of_mass(points):
+def center_of_mass(points: Sequence[float]) -> np.ndarray:
+    """Gets the center of mass of the points in space.
+
+    Parameters
+    ----------
+    points
+        The points to find the center of mass from.
+
+    Returns
+    -------
+    np.ndarray
+        The center of mass of the points.
+    """
     points = [np.array(point).astype("float") for point in points]
     return sum(points) / len(points)
 
 
-def midpoint(point1, point2):
+def midpoint(
+    point1: Sequence[float], point2: Sequence[float]
+) -> Union[float, np.ndarray]:
+    """Gets the midpoint of two points.
+
+    Parameters
+    ----------
+    point1
+        The first point.
+    point2
+        The second point.
+
+    Returns
+    -------
+    Union[float, np.ndarray]
+        The midpoint of the points
+    """
     return center_of_mass([point1, point2])
 
 
-def line_intersection(line1, line2):
-    """
-    Returns intersection point of two lines,
-    each defined with a pair of vectors determining
-    the end points
+def line_intersection(line1: Sequence[float], line2: Sequence[float]) -> np.ndarray:
+    """Returns intersection point of two lines, each defined with
+    a pair of vectors determining the end points.
+
+    Parameters
+    ----------
+    line1
+        The first line.
+    line2
+        The second line.
+
+    Returns
+    -------
+    np.ndarray
+        The intersection points of the two lines which are intersecting.
+
+    Raises
+    ------
+    ValueError
+        Error is produced if the two lines don't intersect with each other
     """
     x_diff = (line1[0][0] - line1[1][0], line2[0][0] - line2[1][0])
     y_diff = (line1[0][1] - line1[1][1], line2[0][1] - line2[1][1])
@@ -346,7 +609,7 @@ def line_intersection(line1, line2):
     return np.array([x, y, 0])
 
 
-def find_intersection(p0, v0, p1, v1, threshold=1e-5):
+def find_intersection(p0, v0, p1, v1, threshold=1e-5) -> np.ndarray:
     """
     Return the intersection of a line passing through p0 in direction v0
     with one passing through p1 in direction v1.  (Or array of intersections
@@ -361,21 +624,21 @@ def find_intersection(p0, v0, p1, v1, threshold=1e-5):
     m, n = np.shape(p0)
     assert n in [2, 3]
 
-    numer = np.cross(v1, p1 - p0)
-    denom = np.cross(v1, v0)
+    numerator = np.cross(v1, p1 - p0)
+    denominator = np.cross(v1, v0)
     if n == 3:
-        d = len(np.shape(numer))
-        new_numer = np.multiply(numer, numer).sum(d - 1)
-        new_denom = np.multiply(denom, numer).sum(d - 1)
-        numer, denom = new_numer, new_denom
+        d = len(np.shape(numerator))
+        new_numerator = np.multiply(numerator, numerator).sum(d - 1)
+        new_denominator = np.multiply(denominator, numerator).sum(d - 1)
+        numerator, denominator = new_numerator, new_denominator
 
-    denom[abs(denom) < threshold] = np.inf  # So that ratio goes to 0 there
-    ratio = numer / denom
+    denominator[abs(denominator) < threshold] = np.inf  # So that ratio goes to 0 there
+    ratio = numerator / denominator
     ratio = np.repeat(ratio, n).reshape((m, n))
     return p0 + ratio * v0
 
 
-def get_winding_number(points):
+def get_winding_number(points: Sequence[float]) -> float:
     total_angle = 0
     for p1, p2 in adjacent_pairs(points):
         d_angle = angle_of_vector(p2) - angle_of_vector(p1)
@@ -384,7 +647,7 @@ def get_winding_number(points):
     return total_angle / TAU
 
 
-def shoelace(x_y):
+def shoelace(x_y: np.ndarray) -> float:
     """2D implementation of the shoelace formula.
 
     Returns
@@ -398,7 +661,7 @@ def shoelace(x_y):
     return area
 
 
-def shoelace_direction(x_y):
+def shoelace_direction(x_y: np.ndarray) -> str:
     """
     Uses the area determined by the shoelace method to determine whether
     the input set of points is directed clockwise or counterclockwise.
@@ -419,17 +682,23 @@ def cross2d(a, b):
         return a[0] * b[1] - b[0] * a[1]
 
 
-def earclip_triangulation(verts, ring_ends):
+def earclip_triangulation(verts: np.ndarray, ring_ends: list) -> list:
+    """Returns a list of indices giving a triangulation
+    of a polygon, potentially with holes.
+
+    Parameters
+    ----------
+    verts
+        verts is a numpy array of points.
+    ring_ends
+        ring_ends is a list of indices indicating where
+    the ends of new paths are.
+
+    Returns
+    -------
+    list
+        A list of indices giving a triangulation of a polygon.
     """
-    Returns a list of indices giving a triangulation
-    of a polygon, potentially with holes
-
-    - verts is a numpy array of points
-
-    - ring_ends is a list of indices indicating where
-    the ends of new paths are
-    """
-
     # First, connect all the rings so that the polygon
     # with holes is instead treated as a (very convex)
     # polygon with one edge.  Do this by drawing connections
@@ -452,11 +721,11 @@ def earclip_triangulation(verts, ring_ends):
             for ring_group in (attached_rings, detached_rings)
         ]
 
-        # Closet point on the atttached rings to an estimated midpoint
+        # Closest point on the attached rings to an estimated midpoint
         # of the detached rings
         tmp_j_vert = midpoint(verts[j_range[0]], verts[j_range[len(j_range) // 2]])
         i = min(i_range, key=lambda i: norm_squared(verts[i] - tmp_j_vert))
-        # Closet point of the detached rings to the aforementioned
+        # Closest point of the detached rings to the aforementioned
         # point of the attached rings
         j = min(j_range, key=lambda j: norm_squared(verts[i] - verts[j]))
         # Recalculate i based on new j
